@@ -54,8 +54,8 @@ class Collision:
             "namespace": "",
         },
     )
-    pose: "Collision.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Collision.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -98,8 +98,8 @@ class Collision:
             defined inside the parent that this frame is attached to.
         """
 
-        pose: "Collision.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Collision.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -124,7 +124,7 @@ class Collision:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -147,7 +147,7 @@ class Collision:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
