@@ -46,8 +46,8 @@ class Collision:
             "required": True,
         },
     )
-    pose: "Collision.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Collision.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -88,7 +88,7 @@ class Collision:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
