@@ -115,8 +115,8 @@ class Joint:
             "namespace": "",
         },
     )
-    pose: "Joint.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Joint.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -163,8 +163,8 @@ class Joint:
         limit: specifies the limits of this joint
         """
 
-        xyz: "Joint.Axis.Xyz" = field(
-            default="0 0 1",
+        xyz: Optional["Joint.Axis.Xyz"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -198,7 +198,7 @@ class Joint:
             """
 
             value: str = field(
-                default="",
+                default="0 0 1",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -348,8 +348,8 @@ class Joint:
         limit:
         """
 
-        xyz: "Joint.Axis2.Xyz" = field(
-            default="0 0 1",
+        xyz: Optional["Joint.Axis2.Xyz"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -383,7 +383,7 @@ class Joint:
             """
 
             value: str = field(
-                default="",
+                default="0 0 1",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -748,7 +748,7 @@ class Joint:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
